from setuptools import setup

setup(
    name="hljm",
    version="1.1.123",
    author="黑龙",
    author_email="2076293320@qq.com",
    description="Description of your library",
    packages=["hljm"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
